@@ -1,6 +1,7 @@
 /*
 
 Copyright (c) 2001-2007 Michael Terry
+Copyright (c) 2009 Paul Ivanov
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -615,6 +616,15 @@ xpad_pad_close (XpadPad *pad)
 	g_signal_emit (pad, signals[CLOSED], 0);
 }
 
+void
+xpad_pad_toggle(XpadPad *pad)
+{
+    if (GTK_WIDGET_VISIBLE (pad)) 
+        xpad_pad_close (pad);
+    else
+        gtk_widget_show (GTK_WIDGET (pad));
+}
+
 static gboolean
 should_confirm_delete (XpadPad *pad)
 {
@@ -1229,7 +1239,7 @@ static void
 menu_about (XpadPad *pad)
 {
 	const gchar *artists[] = {"Michael Terry <mike@mterry.name>", NULL};
-	const gchar *authors[] = {"Michael Terry <mike@mterry.name>", "Jeroen Vermeulen <jtv@xs4all.nl>", NULL};
+	const gchar *authors[] = {"Jeroen Vermeulen <jtv@xs4all.nl>", "Michael Terry <mike@mterry.name>", "Paul Ivanov <pivanov@berkeley.edu>", NULL};
 	const gchar *comments = _("Sticky notes");
 	const gchar *copyright = "© 2001-2007 Michael Terry";
 	/* we use g_strdup_printf because C89 has size limits on static strings */
