@@ -1,10 +1,11 @@
 /*
 
 Copyright (c) 2001-2007 Michael Terry
+Copyright (c) 2009 Paul Ivanov
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
+the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -57,6 +58,8 @@ GtkWidget *xpad_pad_new (XpadPadGroup *group);
 GtkWidget *xpad_pad_new_with_info (XpadPadGroup *group, const gchar *info_filename, gboolean *show);
 GtkWidget *xpad_pad_new_from_file (XpadPadGroup *group, const gchar *filename);
 void xpad_pad_close (XpadPad *pad);
+void xpad_pad_toggle (XpadPad *pad);
+void xpad_pad_save_info (XpadPad *pad);
 
 G_END_DECLS
 
