@@ -1,10 +1,10 @@
 /*
 
-Copyright (c) 2001-2004 Michael Terry
+Copyright (c) 2001-2007 Michael Terry
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
+the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -37,8 +37,6 @@ enum {
 
 struct XpadToolbarPrivate
 {
-	GtkTooltips *tooltips;
-	
 	GtkToolItem *move_button;
 	gboolean move_removed;
 	guint move_index;
@@ -57,13 +55,6 @@ typedef struct
 	const gchar *menu_desc;
 } XpadToolbarButton;
 
-enum
-{
-  PROP_0,
-  PROP_STICKY_ACTIVE,
-  LAST_PROP
-};
-
 enum
 {
 	ACTIVATE_NEW,
@@ -73,7 +64,6 @@ enum
 	ACTIVATE_PREFERENCES,
 	ACTIVATE_PROPERTIES,
 	ACTIVATE_QUIT,
-	ACTIVATE_STICKY,
 	POPUP,
 	POPDOWN,
 	LAST_SIGNAL
@@ -87,8 +77,7 @@ static const XpadToolbarButton buttons[] =
 	{"New", "gtk-new", ACTIVATE_NEW, XPAD_BUTTON_TYPE_BUTTON, N_("Open New Pad"), N_("Add _New to Toolbar")},
 	{"Preferences", "gtk-preferences", ACTIVATE_PREFERENCES, XPAD_BUTTON_TYPE_BUTTON, N_("Edit Preferences"), N_("Add Pr_eferences to Toolbar")},
 	{"Properties", "gtk-properties", ACTIVATE_PROPERTIES, XPAD_BUTTON_TYPE_BUTTON, N_("Edit Pad Properties"), N_("Add Proper_ties to Toolbar")},
-	{"Quit", "gtk-quit", ACTIVATE_QUIT, XPAD_BUTTON_TYPE_BUTTON, N_("Close All Pads"), N_("Add _Quit to Toolbar")},
-	{"Sticky", "xpad-sticky", ACTIVATE_STICKY, XPAD_BUTTON_TYPE_TOGGLE, N_("Toggle Stickiness"), N_("Add _Sticky to Toolbar")},
+	{"Quit", "gtk-quit", ACTIVATE_QUIT, XPAD_BUTTON_TYPE_BUTTON, N_("Close All Pads"), N_("Add Close _All to Toolbar")},
 	{"sep", NULL, 0, XPAD_BUTTON_TYPE_SEPARATOR, NULL, N_("Add a Se_parator to Toolbar")} /* Separator */
 	/*{"Minimize to Tray", "gtk-goto-bottom", 1, N_("Minimize Pads to System Tray")}*/
 };
@@ -100,8 +89,6 @@ static GtkToolItem *xpad_toolbar_button_to_item (XpadToolbar *toolbar, const Xpa
 static void xpad_toolbar_button_activated (GtkToolButton *button);
 static void xpad_toolbar_change_buttons (XpadToolbar *toolbar);
 static void xpad_toolbar_finalize (GObject *object);
-static void xpad_toolbar_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
-static void xpad_toolbar_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 static void xpad_toolbar_add_button (const gchar *button_name);
 static void xpad_toolbar_remove_button (GtkWidget *button);
 static gboolean xpad_toolbar_button_press_event (GtkWidget *widget, GdkEventButton *event);
@@ -130,18 +117,6 @@ xpad_toolbar_class_init (XpadToolbarClass *klass)
 	
 	gtktoolbar_class->popup_context_menu = xpad_toolbar_popup_context_menu;
 	gobject_class->finalize = xpad_toolbar_finalize;
-	gobject_class->set_property = xpad_toolbar_set_property;
-	gobject_class->get_property = xpad_toolbar_get_property;
-	
-	/* Properties */
-	
-	g_object_class_install_property (gobject_class,
-	                                 PROP_STICKY_ACTIVE,
-	                                 g_param_spec_boolean ("sticky-active",
-	                                                       "Sticky Active",
-	                                                       "Whether the sticky button is active",
-	                                                       FALSE,
-	                                                       G_PARAM_READWRITE));
 	
 	/* Signals */
 	
@@ -177,14 +152,6 @@ xpad_toolbar_class_init (XpadToolbarClass *klass)
 		              NULL, NULL,
 		              g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
 	
-	signals[ACTIVATE_STICKY] = 
-		g_signal_new ("activate-sticky",
-		              G_OBJECT_CLASS_TYPE (gobject_class),
-		              G_SIGNAL_RUN_LAST,
-		              G_STRUCT_OFFSET (XpadToolbarClass, activate_sticky),
-		              NULL, NULL,
-		              g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
-	
 	signals[ACTIVATE_PROPERTIES] = 
 		g_signal_new ("activate-properties",
 		              G_OBJECT_CLASS_TYPE (gobject_class),
@@ -233,17 +200,15 @@ xpad_toolbar_init (XpadToolbar *toolbar)
 {
 	toolbar->priv = XPAD_TOOLBAR_GET_PRIVATE (toolbar);
 	
-	toolbar->priv->tooltips = gtk_tooltips_new ();
-	g_object_ref (toolbar->priv->tooltips);
-	gtk_object_sink (GTK_OBJECT (toolbar->priv->tooltips));
-	
 	toolbar->priv->move_motion_handler = 0;
 	toolbar->priv->move_button_release_handler = 0;
 	toolbar->priv->move_key_press_handler = 0;
 	
-	gtk_toolbar_set_tooltips (GTK_TOOLBAR (toolbar), TRUE);
-	gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
-	gtk_toolbar_set_show_arrow (GTK_TOOLBAR (toolbar), FALSE);
+	g_object_set (G_OBJECT (toolbar),
+	              "icon-size", GTK_ICON_SIZE_MENU,
+	              "show-arrow", FALSE,
+	              "toolbar-style", GTK_TOOLBAR_ICONS,
+	              NULL);
 	
 	g_signal_connect_swapped (xpad_settings (), "change-buttons", G_CALLBACK (xpad_toolbar_change_buttons), toolbar);
 	
@@ -255,8 +220,6 @@ xpad_toolbar_finalize (GObject *object)
 {
 	XpadToolbar *toolbar = XPAD_TOOLBAR (object);
 	
-	g_object_unref (toolbar->priv->tooltips);
-	
 	if (toolbar->priv->move_button)
 		g_object_unref (toolbar->priv->move_button);
 	
@@ -323,7 +286,7 @@ xpad_toolbar_button_to_item (XpadToolbar *toolbar, const XpadToolbarButton *butt
 	g_object_set_data (G_OBJECT (item), "xpad-tb", (gpointer) button);
 	
 	if (button->desc)
-		gtk_tool_item_set_tooltip (item, toolbar->priv->tooltips, _(button->desc), _(button->desc));
+		gtk_tool_item_set_tooltip_text (item, _(button->desc));
 	
 	child = gtk_bin_get_child (GTK_BIN (item));
 	if (child)
@@ -647,88 +610,3 @@ xpad_toolbar_popup_context_menu (GtkToolbar *toolbar, gint x, gint y, gint butto
 	
 	return TRUE;
 }
-
-void
-xpad_toolbar_set_sticky_active (XpadToolbar *toolbar, gboolean active)
-{
-	GList *list, *temp;
-	const XpadToolbarButton *tb;
-	
-	list = gtk_container_get_children (GTK_CONTAINER (toolbar));
-	
-	for (temp = list; temp; temp = temp->next)
-	{
-		tb = (const XpadToolbarButton *) g_object_get_data (G_OBJECT (temp->data), "xpad-tb");
-		if (tb && tb->signal == ACTIVATE_STICKY)
-		{
-			g_signal_handlers_block_by_func (GTK_TOOL_ITEM (temp->data), (void *) (xpad_toolbar_button_activated), NULL);
-			gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (temp->data), active);
-			g_signal_handlers_unblock_by_func (GTK_TOOL_ITEM (temp->data), (void *) (xpad_toolbar_button_activated), NULL);
-			break;
-		}
-	}
-	
-	g_list_free (list);
-}
-
-gboolean
-xpad_toolbar_get_sticky_active (XpadToolbar *toolbar)
-{
-	GList *list, *temp;
-	const XpadToolbarButton *tb;
-	gboolean rv = FALSE;
-	
-	list = gtk_container_get_children (GTK_CONTAINER (toolbar));
-	
-	for (temp = list; temp; temp = temp->next)
-	{
-		tb = (const XpadToolbarButton *) g_object_get_data (G_OBJECT (temp->data), "xpad-tb");
-		if (tb->signal == ACTIVATE_STICKY)
-		{
-			rv = gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (temp->data));
-			break;
-		}
-	}
-	
-	g_list_free (list);
-	
-	return rv;
-}
-
-static void
-xpad_toolbar_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
-{
-	XpadToolbar *toolbar;
-	
-	toolbar = XPAD_TOOLBAR (object);
-	
-	switch (prop_id)
-	{
-	case PROP_STICKY_ACTIVE:
-		xpad_toolbar_set_sticky_active (toolbar, g_value_get_boolean (value));
-		break;
-	
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-		break;
-	}
-}
-
-static void
-xpad_toolbar_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
-{
-	XpadToolbar *toolbar;
-	
-	toolbar = XPAD_TOOLBAR (object);
-	
-	switch (prop_id)
-	{
-	case PROP_STICKY_ACTIVE:
-		g_value_set_boolean (value, xpad_toolbar_get_sticky_active (toolbar));
-		break;
-	
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-		break;
-	}
-}
